# MinecraftAutoFisher

[![Documentation Status](https://readthedocs.org/projects/minecraftautofisher/badge/?version=latest)](https://minecraftautofisher.readthedocs.io/en/latest/?badge=latest)

## Description
The goal of fishing in Minecraft is to cast your line and wait until the fishing bobber bobs in the water.
If you click quickly enough when that happens, you'll reel in a fish (or some treasure!).

This program ~~cheats~~ automates this process for you by watching the subtitles on the screen; When the bobber bobs,
it makes a splashing sound and if you have subtitles enabled the text 'Fishing Bobber splashes' appears. This program watches
the screen and right clicks whenever it sees that text, allowing it to keep reeling in fish as long as you leave it running.

## Installation
Requires [tesseract](https://github.com/tesseract-ocr/tesseract)

More details to come

## Usage
This README needs to be updated, see the [docs](https://minecraftautofisher.readthedocs.io) for usage details
